diff --git a/interface/web/themes/default/css/screen/content_ispc.css b/interface/web/themes/default/css/screen/content_ispc.css
index 10803ced91eec810dbd4777c5f7a594a4c56ff53..74f982b5b4a2d97719b72e8094a91082542a8af5 100644
--- a/interface/web/themes/default/css/screen/content_ispc.css
+++ b/interface/web/themes/default/css/screen/content_ispc.css
@@ -234,20 +234,23 @@
 	.dashboard-modules {
 		float:left;
 		width:100px;
-		height: 20px;
+		height: 100px;
 		border:1px dotted #888888;
 		background-color: #cccccc;
 		margin:10px;
-		padding:10px;
 		background-position: center 5px;
 		background-repeat: no-repeat;
-		padding-top: 70px;
 		text-align: center;
 	}
 
-	.dashboard-modules a{
-		color: Black;
-		font-weight: bold;
+	.dashboard-modules a, .dashboard-modules a:hover{
+		color:Black;
+		display:block;
+		font-weight:bold;
+		height:30px;
+		padding-top:70px;
+		width:100px;
+		text-decoration: none;
 	}
 
 	.dashboard-modules.admin { background-image: url('../../icons/x64/system.png') !important; }
diff --git a/interface/web/dashboard/dashboard.php b/interface/web/dashboard/dashboard.php
index 53a745c6e16ed6665af6dbb1a3051c0932606b26..97795a8056ba73b1d5a6e564e255bb6979e2c31f 100644
--- a/interface/web/dashboard/dashboard.php
+++ b/interface/web/dashboard/dashboard.php
@@ -79,17 +79,23 @@ $app->tpl->setVar('welcome_user', $welcome);
 //
 //$app->tpl->setloop('warning', $warning);
 //
-///*
-// * If there is any information to display, do it...
-//*/
-//$info = array();
-//
-//$info[] = array('info_msg' => 'IClaus1');
-//$info[] = array('info_msg' => 'IClaus2');
-//$info[] = array('info_msg' => 'IClaus3');
-//$info[] = array('info_msg' => 'IClaus4');
-//
-//$app->tpl->setloop('info', $info);
+
+
+/*
+ * If there is any information to display, do it...
+*/
+$info = array();
+
+/*
+ * Check the ISPConfig-Version
+*/
+$new_version = @file_get_contents('http://www.ispconfig.org/downloads/ispconfig3_version.txt');
+$new_version = trim($new_version);
+if($new_version != ISPC_APP_VERSION) {
+	$info[] = array('info_msg' => 'There is a new Version of ISPConfig 3 available! <a href="http://www.ispconfig.org">See more...</a>');
+}
+
+$app->tpl->setloop('info', $info);
 
 /*
  * Show all modules, the user is allowed to use